pub fn vdup_lane_s64(a: int64x1_t, const N: i32) -> int64x1_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdup_lane_s64(a: int64x1_t, const N: i32) -> int64x1_tneon only.Set all vector lanes to the same value Arm’s documentation