pub fn vdup_laneq_f32(a: float32x4_t, const N: i32) -> float32x2_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdup_laneq_f32(a: float32x4_t, const N: i32) -> float32x2_tneon only.Set all vector lanes to the same value Arm’s documentation