pub fn vdup_laneq_p16(a: poly16x8_t, const N: i32) -> poly16x4_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdup_laneq_p16(a: poly16x8_t, const N: i32) -> poly16x4_tneon only.Set all vector lanes to the same value Arm’s documentation