pub fn vdup_laneq_u8(a: uint8x16_t, const N: i32) -> uint8x8_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdup_laneq_u8(a: uint8x16_t, const N: i32) -> uint8x8_tneon only.Set all vector lanes to the same value Arm’s documentation