pub fn vdupq_lane_f16(a: float16x4_t, const N: i32) -> float16x8_tAvailable on (AArch64 or ARM64EC) and non-ARM64EC and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdupq_lane_f16(a: float16x4_t, const N: i32) -> float16x8_tneon only.Set all vector lanes to the same value Arm’s documentation