pub fn vdupq_lane_f64(a: float64x1_t, const N: i32) -> float64x2_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdupq_lane_f64(a: float64x1_t, const N: i32) -> float64x2_tneon only.Set all vector lanes to the same value Arm’s documentation