pub fn vdupq_lane_u16(a: uint16x4_t, const N: i32) -> uint16x8_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdupq_lane_u16(a: uint16x4_t, const N: i32) -> uint16x8_tneon only.Set all vector lanes to the same value Arm’s documentation