pub fn vdupq_lane_u8(a: uint8x8_t, const N: i32) -> uint8x16_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdupq_lane_u8(a: uint8x8_t, const N: i32) -> uint8x16_tneon only.Set all vector lanes to the same value Arm’s documentation