pub fn vdupq_laneq_s8(a: int8x16_t, const N: i32) -> int8x16_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Set all vector lanes to the same value Arm’s documentation
pub fn vdupq_laneq_s8(a: int8x16_t, const N: i32) -> int8x16_tneon only.Set all vector lanes to the same value Arm’s documentation